[−][src]Struct google_cloudasset1::BigQueryDestination
A BigQuery destination for exporting assets to.
This type is not used in any activity, and only used as part of another schema.
Fields
table: Option<String>Required. The BigQuery table to which the snapshot result should be written. If this table does not exist, a new table with the given name will be created.
force: Option<bool>If the destination table already exists and this flag is TRUE, the
table will be overwritten by the contents of assets snapshot. If the flag
is FALSE or unset and the destination table already exists, the export
call returns an INVALID_ARGUMEMT error.
dataset: Option<String>Required. The BigQuery dataset in format "projects/projectId/datasets/datasetId", to which the snapshot result should be exported. If this dataset does not exist, the export call returns an INVALID_ARGUMENT error.